Communication channels
======================

Discord
-------
The easiest way to get in touch with us is to via Discord. There we can reply more or less
instantly. The #tonic channel is part of Open Neuromorphic's public space along other channels
for all things revolving around SNN training.
The link to join is https://discord.gg/qubbM4uPuA

Github
------
If Discord is not an option, you can always start a discussion on Github 
`here <https://github.com/neuromorphs/tonic/discussions>`_ or open an issue. It's 
good practice to keep the discussion public, since other people will likely run into
similar issues or have similar questions. 
